@@ -96,6 +96,7 @@ impl ReminderRegexFields {
 pub trait GenericReminder: ToString {
     fn get_time(&self) -> &DateTime<Utc>;
     fn get_id(&self) -> u32;
+    fn is_cron_reminder(&self) -> bool;
     fn to_unescaped_string(&self) -> String;
 }
 
@@ -135,6 +136,10 @@ impl GenericReminder for db::Reminder {
         self.id
     }
 
+    fn is_cron_reminder(&self) -> bool {
+        false
+    }
+
     fn to_unescaped_string(&self) -> String {
         match tz::get_user_timezone(self.user_id) {
             Ok(user_timezone) => {
@@ -199,6 +204,10 @@ impl GenericReminder for db::CronReminder {
         self.id
     }
 
+    fn is_cron_reminder(&self) -> bool {
+        true
+    }
+
     fn to_unescaped_string(&self) -> String {
         match tz::get_user_timezone(self.user_id) {
             Ok(user_timezone) => {
